#!/bin/sh
#############################################################################
#                                                                           #
# IBM Rational Developer for System z 5724-T07                              #
#                                                                           #
# Copyright IBM Corp. 2010 All rights reserved.                             #
# All rights reserved.  US Government Users Restricted Rights -             #
# Use, duplication or disclosure restricted by GSA ADP Schedule Contract    #
# with IBM Corp.                                                            #
#                                                                           #
#############################################################################

# Set the defaults for ECLIPSE_ROOT and WORKSPACE (if necessary)
if [ "$ECLIPSE_ROOT" = "" ]
then
#   ECLIPSE_ROOT=$RDZ80INSTDIR
   ECLIPSE_ROOT=@RDZINSTALLDIR@
fi

if [ "$WORKSPACE" = "" ]
then
   WORKSPACE="$ECLIPSE/workspace"
fi

# Find the eclipse launcher required to run the batch processor
ECLIPSE_LAUNCHER=""
for f in $(find $ECLIPSE_ROOT/plugins -name "org.eclipse.equinox.launcher*.jar" -type f)
do
ECLIPSE_LAUNCHER=$f
done

# Initialize shell script variables
verbose=
gen_conv=
version=
service_name=
language_file=
overwrite=
ann=
cmty=
wspc=

# If no parameters are specified or the ECLIPSE_LAUNCHER cannot be determined,
# then indicate usage error to the user.
if [ $# -gt 0 ] && [ "$ECLIPSE_LAUNCHER" != "" ] 
then
   # Process parameter settings
   while [ $# -gt 0 ]
      do
         case "$1" in
            -whitespacecompat )
                wspc=$1
                shift 1
                ;;
            -f )
               import_file=$2
               shift 2
               ;;
            -s  )
               language_file=-s=$2
               shift 2
               ;;
            -d  )
               WORKSPACE=$2
               shift 2
               ;;
            -e  )
               ECLIPSE_ROOT=$2
               shift 2
               ;;
            -w  )
               service_name=-w=$2
               shift 2
               ;;
            -verbose )
               verbose=$1
               shift 1
               ;;
            -version )
               version=$1
               echo Version 8.0.0
               shift 1
               ;;
            -c  )
               gen_conv=$1
               shift 1
               ;;
            -annot )
               ann=-annot=$2
               shift 2
               ;;
           -commtypes )
               cmty=-commtypes=$2
               shift 2
               ;;
            -overwrite )
               overwrite=-ow=$2
               shift 2
               ;;
            * )
               # Skip unknown parameters
               echo Ignoring parameter: $1
               shift 1
               ;;
         esac
      done

   # import_file and language_file must be defined
   #if [ "$import_file" = "" ] || [ "$language_file" = "" ]
   if [ "$import_file" = "" ]
   then
   #   echo import_file "(-f)" and language_file "(-s)" are required parameters
      echo import_file "(-f)" is a required parameter
   else
      # Determine the console codepage
      currentCodepage=$(locale charmap)

      echo ====================================================
      echo Displaying options being used by the batch processor
      echo ====================================================
      echo wspc: $wspc
      echo import_file: $import_file
      echo language_file: $language_file
      echo WORKSPACE: $WORKSPACE
      echo ECLIPSE_ROOT: $ECLIPSE_ROOT
      echo service_name: $service_name
      echo verbose: $verbose
      echo version: $version
      echo gen_conv: $gen_conv
      echo ann: $ann
      echo cmty: $cmty
      echo overwrite: $overwrite
      echo ECLIPSE_LAUNCHER: $ECLIPSE_LAUNCHER
      echo currentCodepage: $currentCodepage
      echo =====================================================

      # Run the command
      "$ECLIPSE_ROOT/jdk/jre/bin/java" -Xj9 -Xmx256M -verify -Dimport.batch.cp="%currentCodepage" -cp "$ECLIPSE_LAUNCHER" \
           org.eclipse.core.launcher.Main -data "$WORKSPACE" -application com.ibm.etools.xmlent.batch.BatchProcess $language_file $gen_conv \
           $wspc $service_name -file=$import_file $verbose $version $overwrite $ann $cmty

   fi
else
   echo The correct usage of this tool is described in the on-line documentation
   echo for Rational Developer for System z.
fi
